aboutsummaryrefslogtreecommitdiffstats
path: root/apps/pkcs12.c
diff options
context:
space:
mode:
authorDr. David von Oheimb <David.von.Oheimb@siemens.com>2021-08-24 12:27:12 +0200
committerDr. David von Oheimb <dev@ddvo.net>2022-01-11 12:45:12 +0100
commit870871e5df4f47611c38e81d3f50e38cbf362082 (patch)
tree8312c759eb786ebbb037bd6627cfc3c5424e3f1f /apps/pkcs12.c
parent7ee992a5d931ab5ad9df00d2d8e47e1b7a72d7ac (diff)
downloadopenssl-870871e5df4f47611c38e81d3f50e38cbf362082.tar.gz
PKCS12 app: Improve readability w.r.t. enc_flag, renamed to enc_name
Reviewed-by: Dmitry Belyavskiy <beldmit@gmail.com> (Merged from https://github.com/openssl/openssl/pull/16416)
Diffstat (limited to 'apps/pkcs12.c')
-rw-r--r--apps/pkcs12.c11
1 files changed, 5 insertions, 6 deletions
diff --git a/apps/pkcs12.c b/apps/pkcs12.c
index 44b53b0b54..08af7bf3d2 100644
--- a/apps/pkcs12.c
+++ b/apps/pkcs12.c
@@ -155,7 +155,7 @@ const OPTIONS pkcs12_options[] = {
int pkcs12_main(int argc, char **argv)
{
char *infile = NULL, *outfile = NULL, *keyname = NULL, *certfile = NULL;
- char *untrusted = NULL, *ciphername = NULL, *enc_flag = NULL;
+ char *untrusted = NULL, *ciphername = NULL, *enc_name = NULL;
char *passcertsarg = NULL, *passcerts = NULL;
char *name = NULL, *csp_name = NULL;
char pass[PASSWD_BUF_SIZE] = "", macpass[PASSWD_BUF_SIZE] = "";
@@ -238,16 +238,15 @@ int pkcs12_main(int argc, char **argv)
case OPT_NODES:
case OPT_NOENC:
/*
* |enc_flag| stores the name of the option used so it
* can be printed if an error message is output.
*/
- enc_flag = opt_flag() + 1;
+ enc_name = opt_flag() + 1;
enc = NULL;
ciphername = NULL;
break;
case OPT_CIPHER:
- ciphername = opt_unknown();
- enc_flag = opt_unknown();
+ enc_name = ciphername = opt_unknown();
break;
case OPT_ITER:
maciter = iter = opt_int_arg();
@@ -375,7 +374,7 @@ int pkcs12_main(int argc, char **argv)
WARN_EXPORT("cacerts");
if (enc != default_enc)
BIO_printf(bio_err,
- "Warning: output encryption option -%s ignored with -export\n", enc_flag);
+ "Warning: output encryption option -%s ignored with -export\n", enc_name);
} else {
if (keyname != NULL)
WARN_NO_EXPORT("inkey");
@@ -238,16 +238,15 @@ int pkcs12_main(int argc, char **argv)
case OPT_NOENC:
/*
- * |enc_flag| stores the name of the option used so it
+ * |enc_name| stores the name of the option used so it
* can be printed if an error message is output.
*/